@@ -3,10 +3,10 @@
 	/**
 	 * Does an import to a particular table from a text file
 	 *
-	 * $Id: dataimport.php,v 1.6.2.2 2005/03/04 02:32:44 chriskl Exp $
+	 * $Id: dataimport.php,v 1.11 2007/01/22 16:33:01 soranzo Exp $
 	 */
 
-	// Prevent timeouts
+	// Prevent timeouts on large exports (non-safe mode only)
 	if (!ini_get('safe_mode')) set_time_limit(0);
 
 	// Include application functions
@@ -151,6 +151,18 @@
 		} 
 	}
 
+	function loadNULLArray() {
+		$array = array();
+		if (isset($_POST['allowednulls'])) {
+			foreach ($_POST['allowednulls'] as $null_char)
+				$array[] = $null_char;
+		}
+		return $array;
+	}
+
+	function determineNull($field, $null_array) {
+		return in_array($field, $null_array);
+	}
 
 	$misc->printHeader($lang['strimport']);
 	$misc->printTrail('table');
@@ -162,6 +174,7 @@
 		$fd = fopen($_FILES['source']['tmp_name'], 'r');
 		// Check that file was opened successfully
 		if ($fd !== false) {		
+			$null_array = loadNULLArray();
 			$status = $data->beginTransaction();
 			if ($status != 0) {
 				$misc->printMsg($lang['strimporterror']);
@@ -183,7 +196,7 @@
 						break;
 					default:
 						$data->rollbackTransaction();
-						$misc->printMsg($lang['strimporterror']);
+						$misc->printMsg($lang['strimporterror-fileformat']);
 						exit;			
 				}
 			}
@@ -199,7 +212,7 @@
 					else $csv_delimiter = "\t";
 					// Get first line of field names
 					$fields = fgetcsv($fd, $csv_max_line, $csv_delimiter);
-					$row = 1;
+					$row = 2; //We start on the line AFTER the field names
 					while ($line = fgetcsv($fd, $csv_max_line, $csv_delimiter)) {
 						// Build value map
 						$vars = array();
@@ -210,11 +223,13 @@
 						foreach ($fields as $f) {
 							// Check that there is a column
 							if (!isset($line[$i])) {
-								$misc->printMsg(sprintf($lang['strimporterrorline'], $row));
+								$misc->printMsg(sprintf($lang['strimporterrorline-badcolumnnum'], $row));
 								exit;
 							}
 							// Check for nulls
-							if ($line[$i] == '\\N') $nulls[$f] = 'on';
+							if (determineNull($line[$i], $null_array)) {
+								$nulls[$f] = 'on';
+							}
 							// Add to value array
 							$vars[$f] = $line[$i];
 							// Format is always VALUE
@@ -223,6 +238,7 @@
 							$types[$f] = 'text';
 							$i++;
 						}
+
 						$status = $data->insertRow($_REQUEST['table'], $vars, $nulls, $format, $types);
 						if ($status != 0) {
 							$data->rollbackTransaction();
@@ -267,7 +283,7 @@
 	}
 	else {
 		// Upload went wrong
-		$misc->printMsg($lang['strimporterror']);
+		$misc->printMsg($lang['strimporterror-uploadedfile']);
 	}
 	
 	$misc->printFooter();
