@@ -2,7 +2,7 @@
 
 	/**
 	 * Translated by Chih-Hsin Lee [chlee@femh.org.tw]
-	 * $Id: chinese-tr.php,v 1.12 2004/07/12 04:18:41 chriskl Exp $
+	 * $Id: chinese-tr.php,v 1.15 2007/04/24 11:42:07 soranzo Exp $
 	 *
 	 *
 	 */
@@ -87,7 +87,7 @@
 	$lang['stradmin'] = '޲z';
 	$lang['strvacuum'] = 'M';
 	$lang['stranalyze'] = 'R';
-	$lang['strcluster'] = 'O';
+	$lang['strclusterindex'] = 'O';
 	$lang['strclustered'] = 'O?';
 	$lang['strreindex'] = 'د';
 	$lang['strrun'] = '';
@@ -126,7 +126,6 @@
 	$lang['strfileimported'] = 'ɮפwפJC';
 
 	// Error handling
-	$lang['strnoframes'] = 'zݥΤ䴩ج[ss{C';
 	$lang['strbadconfig'] = 'z config.inc.php LġCЧQ config.inc.php-dist إ߱z config.inc.php ɡC';
 	$lang['strnotloaded'] = 'z PHP ҥw˥ݪƮw䴩C';
 	$lang['strbadschema'] = 'wFLĪҦ (schema)C';
@@ -322,7 +321,6 @@
 	$lang['strcachevalue'] = '֨';
 	$lang['strlogcount'] = 'nƶq';
 	$lang['striscycled'] = '`?';
-	$lang['striscalled'] = 'QIs?';
 	$lang['strsequenceneedsname'] = 'zݬzǦCRWC';
 	$lang['strsequencecreated'] = '\إ߷sǦCC';
 	$lang['strsequencecreatedbad'] = 'إ߷sǦC@~ѡC'; 
