@@ -4,7 +4,7 @@
 	 * Dutch Language file for WebDB.
 	 * @maintainer Hugo Jonker [hugo@gewis.win.tue.nl]
 	 *
-	 * $Id: dutch.php,v 1.15 2004/07/12 04:18:41 chriskl Exp $
+	 * $Id: dutch.php,v 1.18 2007/04/24 11:42:07 soranzo Exp $
 	 */
 
 	$lang['applang'] = 'Nederlands';
@@ -13,7 +13,6 @@
 	$lang['appdbencoding'] = 'LATIN1';
 	$lang['applangdir'] = 'ltr';
   
-	$lang['strnoframes'] = 'Deze applicatie maakt gebruik van frames. U heeft een browser nodig, die frames ondersteund, om deze applicatie te gebruiken. ';
 	$lang['strlogin'] = 'Login';
 	$lang['strnotables'] = 'Geen tabellen gevonden.';
 	$lang['strppahome'] = 'phpPgAdmin Homepage';
@@ -117,7 +116,6 @@
 	$lang['strcachevalue'] = 'cache_waarde';
 	$lang['strlogcount'] = 'log_cnt';
 	$lang['striscycled'] = 'is_cyclisch';
-	$lang['striscalled'] = 'is_aangeroepen';
 	$lang['strreset'] =	'Reset';
 
 	// Indicies
@@ -205,7 +203,7 @@
 	$lang['stradmin'] = 'Admin';
 	$lang['strvacuum'] = 'Vacuum';
 	$lang['stranalyze'] = 'Analyzeer';
-	$lang['strcluster'] = 'Cluster';
+	$lang['strclusterindex'] = 'Cluster';
 	$lang['strreindex'] = 'Reindex';
 	$lang['strrun'] = 'Run';
 	$lang['stradd'] = 'Voeg toe';
