@@ -4,7 +4,8 @@
 	 * Japanese language file for phpPgAdmin.
 	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
 	 *
-	 * $Id: japanese.php,v 1.11.2.1 2005/02/09 13:18:12 chriskl Exp $
+	 * $Id: japanese.php,v 1.19 2007/12/27 04:08:35 xzilla Exp $
+	 * EN-Revision: 1.228
 	 */
 
 	// Language and character set
@@ -15,29 +16,34 @@
 	$lang['applangdir'] = 'ltr';
   
 	// Welcome  
-	$lang['strintro'] = '褦phpPgAdminء';
+	$lang['strintro'] = '褦 phpPgAdmin ء';
 	$lang['strppahome'] = 'phpPgAdmin ۡڡ';
 	$lang['strpgsqlhome'] = 'PostgreSQL ۡڡ';
 	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
 	$lang['strlocaldocs'] = 'PostgreSQL ɥ ()';
 	$lang['strreportbug'] = 'Хݡ';
-	$lang['strviewfaq'] = 'FAQ򸫤';
+	$lang['strviewfaq'] = 'FAQ ɽ';
 	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
 	
 	// Basic strings
 	$lang['strlogin'] = '';
-	$lang['strloginfailed'] = '';
+	$lang['strloginfailed'] = '˼Ԥޤ';
 	$lang['strlogindisallowed'] = '󤬵ĤޤǤ';
 	$lang['strserver'] = 'С';
+	$lang['strservers'] = 'С';
+	$lang['strintroduction'] = 'Ƴ';
+	$lang['strhost'] = 'ۥ';
+	$lang['strport'] = 'ݡ';
 	$lang['strlogout'] = '';
 	$lang['strowner'] = 'ͭ';
 	$lang['straction'] = '';
 	$lang['stractions'] = '';
 	$lang['strname'] = '̾';
 	$lang['strdefinition'] = '';
-	$lang['straggregates'] = '';
 	$lang['strproperties'] = 'ץѥƥ';
 	$lang['strbrowse'] = 'ɽ';
+	$lang['strenable']  =  'ͭ';
+	$lang['strdisable']  =  '̵';
 	$lang['strdrop'] = '˴';
 	$lang['strdropped'] = '˴ޤ';
 	$lang['strnull'] = 'NULL';
@@ -55,6 +61,7 @@
 	$lang['stralter'] = 'ѹ';
 	$lang['strok'] = 'OK';
 	$lang['strcancel'] = 'ä';
+	$lang['strac']  =  'ư䴰ͭˤ';
 	$lang['strsave'] = '¸';
 	$lang['strreset'] = 'ꥻå';
 	$lang['strinsert'] = '';
@@ -72,7 +79,6 @@
 	$lang['strrows'] = '쥳';
 	$lang['strrowsaff'] = 'ƶ쥳';
 	$lang['strobjects'] = '֥';
-	$lang['strexample'] = ')';
 	$lang['strback'] = '';
 	$lang['strqueryresults'] = '';
 	$lang['strshow'] = 'ɽ';
@@ -84,15 +90,17 @@
 	$lang['strprimary'] = 'ץ饤ޥ';
 	$lang['strexport'] = 'ݡ';
 	$lang['strimport'] = 'ݡ';
+	$lang['strallowednulls']  =  'NULL ʸĤ';
+	$lang['strbackslashn']  =  '\N';
+	$lang['stremptystring']  =  'ʸ/';
 	$lang['strsql'] = 'SQL';
-	$lang['strgo'] = 'Go';
 	$lang['stradmin'] = '';
 	$lang['strvacuum'] = 'Х塼';
 	$lang['stranalyze'] = '';
-	$lang['strcluster'] = '饹';
-	$lang['strclustered'] = 'Clustered?';
+	$lang['strclusterindex']  =  '饹';
+$lang['strclustered'] = 'Clustered?';
 	$lang['strreindex'] = 'ƥǥå';
-	$lang['strrun'] = '¥';
+	$lang['strexecute']  =  '¹Ԥ';
 	$lang['stradd'] = 'ɲ';
 	$lang['strevent'] = '٥';
 	$lang['strwhere'] = 'Where';
@@ -106,8 +114,6 @@
 	$lang['strseparator'] = ': ';
 	$lang['strexpand'] = 'Ÿ';
 	$lang['strcollapse'] = 'Ĥ';
-	$lang['strexplain'] = '¹Ի';
-	$lang['strexplainanalyze'] = 'ܺٽϲ';
 	$lang['strfind'] = '';
 	$lang['stroptions'] = 'ץ';
 	$lang['strrefresh'] = 'ɽ';
@@ -115,25 +121,47 @@
 	$lang['strdownloadgzipped'] = 'gzip ǰ̤ƥ';
 	$lang['strinfo'] = '';
 	$lang['stroids'] = 'OID ';
-	$lang['stradvanced'] = '٤ʰ';
+	$lang['stradvanced'] = '٤';
 	$lang['strvariables'] = 'ѿ';
 	$lang['strprocess'] = 'ץ';
 	$lang['strprocesses'] = 'ץ';
 	$lang['strsetting'] = '';
 	$lang['streditsql'] = 'SQL Խ';
-	$lang['strruntime'] = '¹Ի: %s ms';
-	$lang['strpaginate'] = 'Paginate results';
-	$lang['struploadscript'] = 'or upload an SQL script:';
+	$lang['strruntime'] = '¹Ի: %s ߥ';
+	$lang['strpaginate'] = '̤ΥڡʬԤ';
+	$lang['struploadscript'] = 'ޤ SQL ץȤ򥢥åץ:';
 	$lang['strstarttime'] = 'ϻ';
 	$lang['strfile'] = 'ե';
 	$lang['strfileimported'] = 'ե򥤥ݡȤޤ';
+	$lang['strtrycred']  =  '٤ƤΥСǤξȤ';
+	$lang['stractionsonmultiplelines']  =  'ʣԤ';
+	$lang['strselectall']  =  '٤򤹤';
+	$lang['strunselectall']  =  '٤';
+	$lang['strlocale']  =  '';
+
+	// User-supplied SQL history
+	$lang['strhistory']  =  '';
+	$lang['strnohistory']  =  '򤬤ޤ';
+	$lang['strclearhistory']  =  'õ뤹';
+	$lang['strdelhistory']  =  '򤫤';
+	$lang['strconfdelhistory']  =  '򤫤餳׵ޤ?';
+	$lang['strconfclearhistory']  =  'õޤ?';
+	$lang['strnodatabaseselected']  =  'ǡ١򤷤Ƥ';
+
+	// Database Sizes
+	$lang['strsize']  =  '';
+	$lang['strbytes']  =  'Х';
+	$lang['strkb']  =  'kB';
+	$lang['strmb']  =  'MB';
+	$lang['strgb']  =  'GB';
+	$lang['strtb']  =  'TB';
 
 	// Error handling
 	$lang['strnoframes'] = 'ΥץꥱѤ뤿ˤϥե졼बѲǽʥ֥饦ɬפǤ';
+	$lang['strnoframeslink'] = 'ե졼ƻȤ';
 	$lang['strbadconfig'] = 'config.inc.php 켰Ǥ config.inc.php-dist ƺɬפޤ';
-	$lang['strnotloaded'] = 'ǡ١򥵥ݡȤ褦 PHP Υѥ롦󥹥ȡ뤬Ƥޤ(ƥˤäƤ php ѥå¾ php-pgsql ѥåΥ󥹥ȡ롦ʤɤɬפǤ)';
-	$lang['strphpversionnotsupported'] = ' PHP ΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
-	$lang['strpostgresqlversionnotsupported'] = ' PostgreSQL ΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
+	$lang['strnotloaded'] = 'ǡ١򥵥ݡȤ褦 PHP Υѥ롦󥹥ȡ뤬Ƥޤconfigure  --with-pgsql ץѤ PHP ƥѥ뤹ɬפޤ';
+	$lang['strpostgresqlversionnotsupported'] = 'ΥС PostgreSQL ϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
 	$lang['strbadschema'] = '̵Υޤꤵޤ';
 	$lang['strbadencoding'] = 'ǡ١ǥ饤ȥ󥳡ɤꤷޤǤ';
 	$lang['strsqlerror'] = 'SQL 顼:';
@@ -145,17 +173,29 @@
 	$lang['strnoreportsdb'] = 'ݡȥǡ١Ƥޤ󡣥ǥ쥯ȥˤ INSTALL եɤǤ';
 	$lang['strnouploads'] = 'ե륢åץɤ̵Ǥ';
 	$lang['strimporterror'] = 'ݡȥ顼';
+	$lang['strimporterror-fileformat']  =  'ݡȥ顼: եưŪ˳Ǥޤ.';
 	$lang['strimporterrorline'] = '%s ܤݡȥ顼Ǥ';
+	$lang['strimporterrorline-badcolumnnum']  =  '%s Ԥǥݡȥ顼:  ԤäƤޤ';
+	$lang['strimporterror-uploadedfile']  =  'ݡȥ顼: С˥ե򥢥åץɤ뤳ȤǤʤ⤷ޤ';
+	$lang['strcannotdumponwindows']  =  'Windows Ǥʣơ֥ȥ̾ΥפϥݡȤƤޤ';
+$lang['strinvalidserverparam']  =  'Attempt to connect with invalid server parameter, possibly someone is trying to hack your system.'; 
+	$lang['strnoserversupplied']  =  'СꤵƤޤ!';
 
 	// Tables
 	$lang['strtable'] = 'ơ֥';
 	$lang['strtables'] = 'ơ֥';
-	$lang['strshowalltables'] = 'ơ֥򸫤';
+	$lang['strshowalltables'] = '٤ƤΥơ֥ɽ';
 	$lang['strnotables'] = 'ơ֥뤬Ĥޤ';
 	$lang['strnotable'] = 'ơ֥뤬Ĥޤ';
 	$lang['strcreatetable'] = 'ơ֥';
+	$lang['strcreatetablelike']  =  'Υơ֥򸵤˿ơ֥';
+	$lang['strcreatetablelikeparent']  =  'ơ֥';
+	$lang['strcreatelikewithdefaults']  =  'DEFAULT ޤ';
+	$lang['strcreatelikewithconstraints']  =  'CONSTRAINTS ޤ';
+	$lang['strcreatelikewithindexes']  =  'INDEX ޤ';
 	$lang['strtablename'] = 'ơ֥̾';
 	$lang['strtableneedsname'] = 'ơ֥̾ꤹɬפޤ';
+$lang['strtablelikeneedslike']  =  'You must give a table to copy properties from.';
 	$lang['strtableneedsfield'] = 'ʤȤĤΥեɤꤷʤФʤޤ';
 	$lang['strtableneedscols'] = 'ͭʥꤷʤФʤޤ';
 	$lang['strtablecreated'] = 'ơ֥ޤ';
@@ -169,6 +209,7 @@
 	$lang['strinsertrow'] = '쥳ɤ';
 	$lang['strrowinserted'] = '쥳ɤޤ';
 	$lang['strrowinsertedbad'] = '쥳ɤ˼Ԥޤ';
+	$lang['strrowduplicate']  =  '쥳ɤ˼Ԥʣߤޤ';
 	$lang['streditrow'] = '쥳Խ';
 	$lang['strrowupdated'] = '쥳ɤ򹹿ޤ';
 	$lang['strrowupdatedbad'] = '쥳ɤι˼Ԥޤ';
@@ -177,13 +218,11 @@
 	$lang['strrowdeleted'] = '쥳ɤޤ';
 	$lang['strrowdeletedbad'] = '쥳ɤκ˼Ԥޤ';
 	$lang['strinsertandrepeat'] = 'ȷ֤';
-	$lang['strnumcols'] = 'Number of columns';
-	$lang['strcolneedsname'] = 'You must specify a name for the column';
-	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';
-	$lang['strselectallfields'] = 'ƤΥեɤ';
+	$lang['strnumcols'] = 'ο';
+	$lang['strcolneedsname'] = '̾ꤷʤФޤ';
+	$lang['strselectallfields'] = '٤ƤΥեɤ򤹤';
 	$lang['strselectneedscol'] = 'ʤȤ쥫ɬפǤ';
 	$lang['strselectunary'] = 'ñΥڥ졼ͤĤȤǤޤ';
-	$lang['straltercolumn'] = 'ѹ';
 	$lang['strcolumnaltered'] = 'ѹޤ';
 	$lang['strcolumnalteredbad'] = 'ѹ˼Ԥޤ';
 	$lang['strconfdropcolumn'] = '˥%sפơ֥%sפ˴ƤǤ?';
@@ -192,31 +231,39 @@
 	$lang['straddcolumn'] = 'ɲ';
 	$lang['strcolumnadded'] = 'ɲäޤ';
 	$lang['strcolumnaddedbad'] = 'ɲä˼Ԥޤ';
-	$lang['strdataonly'] = 'ǡΤ';
 	$lang['strcascade'] = '';
 	$lang['strtablealtered'] = 'ơ֥ѹޤ';
 	$lang['strtablealteredbad'] = 'ơ֥ѹ˼Ԥޤ';
 	$lang['strdataonly'] = 'ǡΤ';
 	$lang['strstructureonly'] = '¤Τ';
 	$lang['strstructureanddata'] = '¤ȥǡ';
-	$lang['strtabbed'] = 'Tabbed';
+	$lang['strtabbed'] = 'ֶڤ';
 	$lang['strauto'] = 'ư';
-	$lang['strconfvacuumtable'] = ' "%s"  vacuum ޤ?';
-	$lang['strestimatedrowcount'] = 'Estimated Row Count';
+	$lang['strconfvacuumtable'] = 'ˡ%sפХ塼षޤ?';
+	$lang['strconfanalyzetable']  =  '%sפʬ(ANALYZE)ޤ?';
+	$lang['strestimatedrowcount'] = 'ɾѥ쥳ɿ';
+	$lang['strspecifytabletoanalyze']  =  'ơ֥ϤˤϾʤȤ 1 ĻꤷʤФʤޤ';
+	$lang['strspecifytabletoempty']  =  'ơ֥ˤˤϾʤȤ 1 ĻꤷʤФʤޤ';
+	$lang['strspecifytabletodrop']  =  'ơ֥˴ˤϾʤȤ 1 ĻꤷʤФʤޤ';
+	$lang['strspecifytabletovacuum']  =  'ơ֥Х塼हˤϾʤȤ 1 ĻꤷʤФʤޤ';
 
+	// Columns
+	$lang['strcolprop']  =  'Υץѥƥ';
+	$lang['strnotableprovided']  =  'ơ֥뤬ꤵƤޤ!';
+		
 	// Users
 	$lang['struser'] = '桼';
 	$lang['strusers'] = '桼';
 	$lang['strusername'] = '桼̾';
 	$lang['strpassword'] = 'ѥ';
-	$lang['strsuper'] = 'ѡ桼?';
+	$lang['strsuper'] = 'ѡ桼Ǥ?';
 	$lang['strcreatedb'] = 'ǡ١ޤ?';
 	$lang['strexpires'] = 'ͭ';
 	$lang['strsessiondefaults'] = 'åǥե';
 	$lang['strnousers'] = '桼Ĥޤ';
 	$lang['struserupdated'] = '桼򹹿ޤ';
 	$lang['struserupdatedbad'] = '桼ι˼Ԥޤ';
-	$lang['strshowallusers'] = 'ƤΥ桼򸫤롣';
+	$lang['strshowallusers'] = '٤ƤΥ桼ɽ';
 	$lang['strcreateuser'] = '桼';
 	$lang['struserneedsname'] = '桼̾ɬפǤ';
 	$lang['strusercreated'] = '桼ޤ';
@@ -233,11 +280,11 @@
 		
 	// Groups
 	$lang['strgroup'] = '롼';
-	$lang['strgroups'] = '롼װ';
+	$lang['strgroups'] = '롼';
+	$lang['strshowallgroups']  =  '٤ƤΥ롼פɽ';
 	$lang['strnogroup'] = '롼פޤ';
 	$lang['strnogroups'] = '롼פĤޤ';
-	$lang['strcreategroup'] = '롼׺';
-	$lang['strshowallgroups'] = '롼פ򸫤';
+	$lang['strcreategroup'] = '롼פ';
 	$lang['strgroupneedsname'] = '롼̾ꤷʤФʤޤ';
 	$lang['strgroupcreated'] = '롼פޤ';
 	$lang['strgroupcreatedbad'] = '롼פκ˼Ԥޤ';	
@@ -245,7 +292,9 @@
 	$lang['strgroupdropped'] = '롼פ˴ޤ';
 	$lang['strgroupdroppedbad'] = '롼פ˴˼Ԥޤ';
 	$lang['strmembers'] = 'С';
-	$lang['straddmember'] = 'Сɲ';
+	$lang['strmemberof']  =  'Υ롼פΥС:';
+	$lang['stradminmembers']  =  'С';
+	$lang['straddmember'] = 'Сɲä';
 	$lang['strmemberadded'] = 'Сɲäޤ';
 	$lang['strmemberaddedbad'] = 'Сɲä˼Ԥޤ';
 	$lang['strdropmember'] = 'С˴';
@@ -253,6 +302,28 @@
 	$lang['strmemberdropped'] = 'С˴ޤ';
 	$lang['strmemberdroppedbad'] = 'С˴˼Ԥޤ';
 
+	// Roles
+	$lang['strrole']  =  '';
+	$lang['strroles']  =  '';
+	$lang['strshowallroles']  =  '٤ƤΥɽ';
+	$lang['strnoroles']  =  '뤬Ĥޤ';
+	$lang['strinheritsprivs']  =  'øѤޤ?';
+	$lang['strcreaterole']  =  '';
+	$lang['strcancreaterole']  =  'Ǥޤ?';
+	$lang['strrolecreated']  =  'ޤ';
+	$lang['strrolecreatedbad']  =  'κ˼Ԥޤ';
+	$lang['strrolealtered']  =  'ѹޤ';
+	$lang['strrolealteredbad']  =  'ѹ˼Ԥޤ';
+	$lang['strcanlogin']  =  'Ǥޤ?';
+	$lang['strconnlimit']  =  '³';
+	$lang['strdroprole']  =  '˴';
+	$lang['strconfdroprole']  =  '˥%sפ˴ޤ?';
+	$lang['strroledropped']  =  '˴ޤ';
+	$lang['strroledroppedbad']  =  '˴˼Ԥޤ';
+	$lang['strnolimit']  =  '¤ʤ';
+	$lang['strnever']  =  'Never';
+	$lang['strroleneedsname']  =  '̾ꤷʤФʤޤ';
+
 	// Privileges
 	$lang['strprivilege'] = 'ø';
 	$lang['strprivileges'] = 'ø';
@@ -268,9 +339,8 @@
 	// Databases
 	$lang['strdatabase'] = 'ǡ١';
 	$lang['strdatabases'] = 'ǡ١';
-	$lang['strshowalldatabases'] = 'ǡ١򸫤';
-	$lang['strnodatabase'] = 'ǡ١Ĥޤ';
-	$lang['strnodatabases'] = 'ǡ١ޤ';
+	$lang['strshowalldatabases'] = '٤ƤΥǡ١ɽ';
+	$lang['strnodatabases'] = 'ǡ١ޤäޤ';
 	$lang['strcreatedatabase'] = 'ǡ١';
 	$lang['strdatabasename'] = 'ǡ١̾';
 	$lang['strdatabaseneedsname'] = 'ǡ١̾ꤷʤФʤޤ';
@@ -292,12 +362,15 @@
 	$lang['strforce'] = '';
 	$lang['strsignalsent'] = 'ʥ';
 	$lang['strsignalsentbad'] = 'ʥ˼Ԥޤ';
-	$lang['strallobjects'] = '٤ƤΥ֥Ȱ';
+	$lang['strallobjects'] = '٤ƤΥ֥';
+	$lang['strdatabasealtered']  =  'ǡ١ѹޤ';
+	$lang['strdatabasealteredbad']  =  'ǡ١ѹ˼Ԥޤ';
+	$lang['strspecifydatabasetodrop']  =  'ǡ١˴ˤϾʤȤ 1 ĻꤷʤФʤޤ';
 
 	// Views
 	$lang['strview'] = 'ӥ塼';
 	$lang['strviews'] = 'ӥ塼';
-	$lang['strshowallviews'] = 'ӥ塼ɽ';
+	$lang['strshowallviews'] = '٤ƤΥӥ塼ɽ';
 	$lang['strnoview'] = 'ӥ塼ޤ';
 	$lang['strnoviews'] = 'ӥ塼Ĥޤ';
 	$lang['strcreateview'] = 'ӥ塼';
@@ -312,17 +385,23 @@
 	$lang['strviewdroppedbad'] = 'ӥ塼˴˼Ԥޤ';
 	$lang['strviewupdated'] = 'ӥ塼򹹿ޤ';
 	$lang['strviewupdatedbad'] = 'ӥ塼ι˼Ԥޤ';
-	$lang['strviewlink'] = 'Linking Keys';
+	$lang['strviewlink'] = '󥯤';
 	$lang['strviewconditions'] = 'ɲþ';
 	$lang['strcreateviewwiz'] = 'ɤǥӥ塼';
+	$lang['strrenamedupfields']  =  'ʣܤ̾ѹ';
+	$lang['strdropdupfields']  =  'ʣܤ˴';
+	$lang['strerrordupfields']  =  'ʣܤΥ顼Ǥ';
+	$lang['strviewaltered']  =  'ӥ塼ѹޤ';
+	$lang['strviewalteredbad']  =  'ӥ塼ѹ˼Ԥޤ';
+	$lang['strspecifyviewtodrop']  =  'ӥ塼˴ˤϾʤȤ 1 ĻꤷʤФʤޤ';
 
 	// Sequences
 	$lang['strsequence'] = '';
-	$lang['strsequences'] = '󥹰';
-	$lang['strshowallsequences'] = '󥹤򸫤';
+	$lang['strsequences'] = '';
+	$lang['strshowallsequences'] = '٤ƤΥ󥹤ɽ';
 	$lang['strnosequence'] = '󥹤ޤ';
 	$lang['strnosequences'] = '󥹤Ĥޤ';
-	$lang['strcreatesequence'] = '󥹺';
+	$lang['strcreatesequence'] = '󥹤';
 	$lang['strlastvalue'] = 'ǽ';
 	$lang['strincrementby'] = 'ÿ';	
 	$lang['strstartvalue'] = '';
@@ -330,8 +409,8 @@
 	$lang['strminvalue'] = 'Ǿ';
 	$lang['strcachevalue'] = 'å';
 	$lang['strlogcount'] = '';
-	$lang['striscycled'] = 'Is Cycled?';
-	$lang['striscalled'] = 'Is Called?';
+$lang['strcancycle']  =  'Can cycle?';
+$lang['striscalled']  =  'Will increment last value before returning next value (is_called)?';
 	$lang['strsequenceneedsname'] = '̾ꤷʤФʤޤ';
 	$lang['strsequencecreated'] = '󥹤ޤ';
 	$lang['strsequencecreatedbad'] = '󥹤κ˼Ԥޤ'; 
@@ -340,12 +419,21 @@
 	$lang['strsequencedroppedbad'] = '󥹤˴˼Ԥޤ';
 	$lang['strsequencereset'] = '󥹥ꥻåȤԤޤ';
 	$lang['strsequenceresetbad'] = '󥹤ΥꥻåȤ˼Ԥޤ'; 
+	$lang['strsequencealtered']  =  '󥹤ѹޤ';
+	$lang['strsequencealteredbad']  =  '󥹤ѹ˼Ԥޤ';
+	$lang['strsetval']  =  'ͤꤹ';
+	$lang['strsequencesetval']  =  'ͤꤷޤ';
+	$lang['strsequencesetvalbad']  =  'ͤ˼Ԥޤ';
+	$lang['strnextval']  =  'ͤä';
+	$lang['strsequencenextval']  =  'ͤäޤ';
+	$lang['strsequencenextvalbad']  =  'ͤä˼Ԥޤ';
+	$lang['strspecifysequencetodrop']  =  '󥹤˴ˤϾʤȤ 1 ĻꤷʤФʤޤ';
 
 	// Indexes
 	$lang['strindex'] = 'ǥå';
 	$lang['strindexes'] = 'ǥå';
 	$lang['strindexname'] = 'ǥå̾';
-	$lang['strshowallindexes'] = 'ǥåɽ';
+	$lang['strshowallindexes'] = '٤ƤΥǥåɽ';
 	$lang['strnoindex'] = 'ǥåޤ';
 	$lang['strnoindexes'] = 'ǥåĤޤ';
 	$lang['strcreateindex'] = 'ǥå';
@@ -354,14 +442,14 @@
 	$lang['strindexneedsname'] = 'ͭʥǥå̾ꤷʤФޤ';
 	$lang['strindexneedscols'] = 'ͭʥꤷʤФޤ';
 	$lang['strindexcreated'] = 'ǥåޤ';
-	$lang['strindexcreatedbad'] = 'ǥå˼Ԥޤ';
+	$lang['strindexcreatedbad'] = 'ǥåκ˼Ԥޤ';
 	$lang['strconfdropindex'] = '˥ǥå%sפ˴ޤ?';
 	$lang['strindexdropped'] = 'ǥå˴ޤ';
 	$lang['strindexdroppedbad'] = 'ǥå˴˼Ԥޤ';
 	$lang['strkeyname'] = '̾';
 	$lang['struniquekey'] = 'ˡ';
 	$lang['strprimarykey'] = 'ץ饤ޥꥭ';
- 	$lang['strindextype'] = 'ǥå';
+	$lang['strindextype'] = 'ǥå';
 	$lang['strtablecolumnlist'] = 'ơ֥Υ';
 	$lang['strindexcolumnlist'] = 'ǥåΥ';
 	$lang['strconfcluster'] = 'ˡ%sפ򥯥饹ˤޤ?';
@@ -371,7 +459,7 @@
 	// Rules
 	$lang['strrules'] = '롼';
 	$lang['strrule'] = '롼';
-	$lang['strshowallrules'] = '롼ɽ';
+	$lang['strshowallrules'] = '٤ƤΥ롼ɽ';
 	$lang['strnorule'] = '롼뤬ޤ';
 	$lang['strnorules'] = '롼뤬Ĥޤ';
 	$lang['strcreaterule'] = '롼';
@@ -384,28 +472,29 @@
 	$lang['strruledroppedbad'] = '롼˴˼Ԥޤ';
 
 	// Constraints
+	$lang['strconstraint'] = '';
 	$lang['strconstraints'] = '';
-	$lang['strshowallconstraints'] = 'ɽ';
+	$lang['strshowallconstraints'] = '٤Ƥθɽ';
 	$lang['strnoconstraints'] = '󤬤ޤ';
-	$lang['strcreateconstraint'] = 'κ';
+	$lang['strcreateconstraint'] = '';
 	$lang['strconstraintcreated'] = 'ޤ';
 	$lang['strconstraintcreatedbad'] = 'κ˼Ԥޤ';
 	$lang['strconfdropconstraint'] = '˸%sפǡ١%sפ˴ޤ?';
 	$lang['strconstraintdropped'] = '˴ޤ';
 	$lang['strconstraintdroppedbad'] = '˴˼Ԥޤ';
-	$lang['straddcheck'] = 'åɲ';
+	$lang['straddcheck'] = 'ɲä';
 	$lang['strcheckneedsdefinition'] = 'ˤɬפǤ';
 	$lang['strcheckadded'] = 'ɲäޤ';
 	$lang['strcheckaddedbad'] = 'ɲä˼Ԥޤ';
-	$lang['straddpk'] = 'ץ饤ޥꥭɲ';
+	$lang['straddpk'] = 'ץ饤ޥꥭɲä';
 	$lang['strpkneedscols'] = 'ץ饤ޥꥭϾʤȤ쥫ɬפȤޤ';
 	$lang['strpkadded'] = 'ץ饤ޥꥭɲäޤ';
 	$lang['strpkaddedbad'] = 'ץ饤ޥꥭɲä˼Ԥޤ';
-	$lang['stradduniq'] = 'ˡɲ';
+	$lang['stradduniq'] = 'ˡɲä';
 	$lang['struniqneedscols'] = 'ˡϾʤȤ쥫ɬפȤޤ';
 	$lang['struniqadded'] = 'ˡɲäޤ';
 	$lang['struniqaddedbad'] = 'ˡɲä˼Ԥޤ';
-	$lang['straddfk'] = 'ɲ';
+	$lang['straddfk'] = 'ɲä';
 	$lang['strfkneedscols'] = 'ϾʤȤ쥫ɬפȤޤ';
 	$lang['strfkneedstarget'] = 'ϥåȥơ֥ɬפȤޤ';
 	$lang['strfkadded'] = 'ɲäޤ';
@@ -418,15 +507,14 @@
 	// Functions
 	$lang['strfunction'] = 'ؿ';
 	$lang['strfunctions'] = 'ؿ';
-	$lang['strshowallfunctions'] = 'ؿɽ';
+	$lang['strshowallfunctions'] = '٤ƴؿɽ';
 	$lang['strnofunction'] = 'ؿޤ';
 	$lang['strnofunctions'] = 'ؿĤޤ';
 	$lang['strcreateplfunction'] = 'SQL/PL ؿ';
-	$lang['strcreateinternalfunction'] = 'Create internal function';
+	$lang['strcreateinternalfunction'] = 'ؿ';
 	$lang['strcreatecfunction'] = 'C ؿ';
 	$lang['strfunctionname'] = 'ؿ̾';
 	$lang['strreturns'] = '֤';
-	$lang['strarguments'] = '';
 	$lang['strproglanguage'] = 'ץߥ󥰸';
 	$lang['strfunctionneedsname'] = 'ؿ̾ꤷʤФʤޤ';
 	$lang['strfunctionneedsdef'] = 'ؿ򤷤ʤФʤꤢ';
@@ -439,11 +527,27 @@
 	$lang['strfunctionupdatedbad'] = 'ؿι˼Ԥޤ';
 	$lang['strobjectfile'] = '֥ȥե';
 	$lang['strlinksymbol'] = '󥯥ܥ';
+	$lang['strarguments']  =  '';
+	$lang['strargmode']  =  '⡼';
+	$lang['strargtype']  =  '';
+	$lang['strargadd']  =  '¾ΰɲä';
+	$lang['strargremove']  =  'ΰ';
+	$lang['strargnoargs']  =  'δؿϤĤΰʤǤ礦';
+$lang['strargenableargs']  =  'Enable arguments being passed to this function.';
+	$lang['strargnorowabove']  =  'ιԤξ˹ԤɬפǤ';
+	$lang['strargnorowbelow']  =  'ιԤβ˹ԤɬפǤ';
+	$lang['strargraise']  =  '˰ưޤ';
+	$lang['strarglower']  =  '˰ưޤ';
+	$lang['strargremoveconfirm']  =  'ˤΰޤ? ᤹ȤǤޤThis CANNOT be undone';
+$lang['strfunctioncosting']  =  'Function Costing';
+$lang['strresultrows']  =  'Result Rows';
+$lang['strexecutioncost']  =  'Execution Cost';
+	$lang['strspecifyfunctiontodrop']  =  'ؿ˴ˤϾʤȤ 1 ĻꤷʤФʤޤ';
 
 	// Triggers
 	$lang['strtrigger'] = 'ȥꥬ';
 	$lang['strtriggers'] = 'ȥꥬ';
-	$lang['strshowalltriggers'] = 'ȥꥬɽ';
+	$lang['strshowalltriggers'] = '٤ƤΥȥꥬɽ';
 	$lang['strnotrigger'] = 'ȥꥬޤ';
 	$lang['strnotriggers'] = 'ȥꥬĤޤ';
 	$lang['strcreatetrigger'] = 'ȥꥬ';
@@ -452,31 +556,43 @@
 	$lang['strtriggercreated'] = 'ȥꥬޤ';
 	$lang['strtriggercreatedbad'] = 'ȥꥬκ˼Ԥޤ';
 	$lang['strconfdroptrigger'] = '˥ȥꥬ%sפǡ١%sפ˴ޤ?';
+	$lang['strconfenabletrigger']  =  'ˡ%2$sפΥȥꥬ%1$sפͭˤޤ?';
+	$lang['strconfdisabletrigger']  =  'ˡ%2$sפΥȥꥬ%1$sפ̵ˤޤ?';
 	$lang['strtriggerdropped'] = 'ȥꥬ˴ޤ';
 	$lang['strtriggerdroppedbad'] = 'ȥꥬ˴˼Ԥޤ';
+	$lang['strtriggerenabled']  =  'ȥꥬͭˤޤ';
+	$lang['strtriggerenabledbad']  =  'ȥꥬͭ˼Ԥޤ';
+	$lang['strtriggerdisabled']  =  'ȥꥬ̵ˤޤ';
+	$lang['strtriggerdisabledbad']  =  'ȥꥬ̵˼Ԥޤ';
 	$lang['strtriggeraltered'] = 'ȥꥬѹޤ';
 	$lang['strtriggeralteredbad'] = 'ȥꥬѹ˼Ԥޤ';
+$lang['strforeach']  =  'For each';
 
 	// Types
 	$lang['strtype'] = 'ǡ';
 	$lang['strtypes'] = 'ǡ';
-	$lang['strshowalltypes'] = 'ǡɽ';
+	$lang['strshowalltypes'] = '٤ƤΥǡɽ';
 	$lang['strnotype'] = 'ǡޤ';
 	$lang['strnotypes'] = 'ǡĤޤǤ';
-	$lang['strcreatetype'] = 'ǡκ';
+	$lang['strcreatetype'] = 'ǡ';
 	$lang['strcreatecomptype'] = 'ʣ緿';
+$lang['strcreateenumtype']  =  'Create enum type';
 	$lang['strtypeneedsfield'] = 'ʤȤ 1 ĤΥեɤꤷʤФʤޤ';
+	$lang['strtypeneedsvalue']  =  'ʤȤ 1 ĤͤꤷʤФʤޤ';
 	$lang['strtypeneedscols'] = 'ͭʥեɤοꤷʤФʤޤ';
-	$lang['strtypename'] = 'ǡ̾';
+$lang['strtypeneedsvals']  =  'You must specify a valid number of values.';
 	$lang['strinputfn'] = 'ϴؿ';
 	$lang['stroutputfn'] = 'ϴؿ';
-	$lang['strpassbyval'] = 'Passed by val?';
+$lang['strpassbyval'] = 'Passed by val?';
 	$lang['stralignment'] = '饤';
 	$lang['strelement'] = '';
 	$lang['strdelimiter'] = 'ǥߥ꥿';
 	$lang['strstorage'] = 'ȥ졼';
 	$lang['strfield'] = 'ե';
+$lang['strvalue']  =  'Value';
+$lang['strvalue']  =  'Value';
 	$lang['strnumfields'] = 'եɿ';
+$lang['strnumvalues']  =  'Num. of values';
 	$lang['strtypeneedsname'] = '̾ꤷʤФʤޤ';
 	$lang['strtypeneedslen'] = 'ǡĹꤷʤФʤޤ';
 	$lang['strtypecreated'] = 'ǡޤ';
@@ -484,18 +600,20 @@
 	$lang['strconfdroptype'] = '˥ǡ%sפ˴ޤ?';
 	$lang['strtypedropped'] = 'ǡ˴ޤ';
 	$lang['strtypedroppedbad'] = 'ǡ˴˼Ԥޤ';
-	$lang['strflavor'] = 'Flavor';
+	$lang['strflavor'] = '';
 	$lang['strbasetype'] = '';
 	$lang['strcompositetype'] = 'ʣ緿';
-	$lang['strpseudotype'] = 'Pseudo';
+	$lang['strpseudotype'] = 'ǡ';
+$lang['strenum']  =  'Enum';
+$lang['strenumvalues']  =  'Enum Values';
 
 	// Schemas
 	$lang['strschema'] = '';
-	$lang['strschemas'] = 'ް';
-	$lang['strshowallschemas'] = 'ޤɽ';
+	$lang['strschemas'] = '';
+	$lang['strshowallschemas'] = '٤ƤΥޤɽ';
 	$lang['strnoschema'] = 'ޤޤ';
 	$lang['strnoschemas'] = 'ޤĤޤ';
-	$lang['strcreateschema'] = '޺';
+	$lang['strcreateschema'] = 'ޤ';
 	$lang['strschemaname'] = '̾';
 	$lang['strschemaneedsname'] = '̾ꤹɬפޤ';
 	$lang['strschemacreated'] = 'ޤޤ';
@@ -505,14 +623,15 @@
 	$lang['strschemadroppedbad'] = 'ޤ˴˼Ԥޤ';
 	$lang['strschemaaltered'] = 'ޤѹޤ';
 	$lang['strschemaalteredbad'] = 'ޤѹ˼Ԥޤ';
-        $lang['strsearchpath'] = '޸ѥ';
+	$lang['strsearchpath'] = '޸ѥ';
+	$lang['strspecifyschematodrop']  =  'ޤ˴ˤϾʤȤ 1 ĻꤷʤФʤޤ';
 
 	// Reports
 	$lang['strreport'] = 'ݡ';
-	$lang['strreports'] = 'ݡȰ';
-	$lang['strshowallreports'] = 'ݡȤ򸫤';
+	$lang['strreports'] = 'ݡ';
+	$lang['strshowallreports'] = '٤ƤΥݡȤɽ';
 	$lang['strnoreports'] = 'ݡȤĤޤ';
-	$lang['strcreatereport'] = 'ݡȺ';
+	$lang['strcreatereport'] = 'ݡȤ';
 	$lang['strreportdropped'] = 'ݡȤ˴ޤ';
 	$lang['strreportdroppedbad'] = 'ݡȤ˴˼Ԥޤ';
 	$lang['strconfdropreport'] = '˥ݡȡ%sפ˴ޤ?';
@@ -524,7 +643,7 @@
 	// Domains
 	$lang['strdomain'] = 'ɥᥤ';
 	$lang['strdomains'] = 'ɥᥤ';
-	$lang['strshowalldomains'] = 'ɥᥤ򸫤';
+	$lang['strshowalldomains'] = '٤ƤΥɥᥤɽ';
 	$lang['strnodomains'] = 'ɥᥤ󤬤ޤ';
 	$lang['strcreatedomain'] = 'ɥᥤ';
 	$lang['strdomaindropped'] = 'ɥᥤ˴ޤ';
@@ -538,8 +657,8 @@
 
 	// Operators
 	$lang['stroperator'] = '黻';
-	$lang['stroperators'] = '黻Ұ';
-	$lang['strshowalloperators'] = '黻Ҥ򸫤';
+	$lang['stroperators'] = '黻';
+	$lang['strshowalloperators'] = '٤Ƥα黻Ҥɽ';
 	$lang['strnooperator'] = '黻ҤĤޤ';
 	$lang['strnooperators'] = '黻ҥ饹Ĥޤ';
 	$lang['strcreateoperator'] = '黻Ҥޤ';
@@ -563,13 +682,13 @@
 	$lang['stroperatordroppedbad'] = '黻Ҥ˴˼Ԥޤ';
 
 	// Casts
-	$lang['strcasts'] = '㥹Ȱ';
+	$lang['strcasts'] = '㥹';
 	$lang['strnocasts'] = '㥹ȤĤޤ';
 	$lang['strsourcetype'] = '';
 	$lang['strtargettype'] = 'åȥ';
 	$lang['strimplicit'] = '';
-	$lang['strinassignment'] = 'In assignment';
-	$lang['strbinarycompat'] = '(Хʥߴ)';
+$lang['strinassignment'] = 'In assignment';
+	$lang['strbinarycompat'] = '(Хʥ꡼ߴ)';
 	
 	// Conversions
 	$lang['strconversions'] = 'Ѵ';
@@ -580,7 +699,7 @@
 	// Languages
 	$lang['strlanguages'] = '';
 	$lang['strnolanguages'] = '줬¸ߤޤ';
-	$lang['strtrusted'] = 'Trusted';
+$lang['strtrusted'] = 'Trusted';
 	
 	// Info
 	$lang['strnoinfo'] = 'ͭʾ󤬤ޤ';
@@ -589,9 +708,29 @@
 	$lang['strchildtables'] = 'ҥơ֥';
 
 	// Aggregates
-	$lang['straggregates'] = 'װ';
+	$lang['straggregate']  =  '';
+	$lang['straggregates'] = '';
 	$lang['strnoaggregates'] = 'פޤ';
-	$lang['stralltypes'] = '(ƤΥ)';
+	$lang['stralltypes'] = '(٤Ƥμ)';
+	$lang['strcreateaggregate']  =  'פ';
+	$lang['straggrbasetype']  =  'ϥǡμ';
+	$lang['straggrsfunc']  =  'ܴؿ';
+	$lang['straggrstype']  =  '֥ǡμ';
+	$lang['straggrffunc']  =  'λؿ';
+	$lang['straggrinitcond']  =  '';
+	$lang['straggrsortop']  =  '';
+	$lang['strconfdropaggregate']  =  '˽ס%sפ˴ޤ?';
+	$lang['straggregatedropped']  =  'פ˴ޤ';
+	$lang['straggregatedroppedbad']  =  'פ˴˼Ԥޤ';
+	$lang['straggraltered']  =  'פѹޤ';
+	$lang['straggralteredbad']  =  'פѹ˼Ԥޤ';
+	$lang['straggrneedsname']  =  'פ̾ꤷʤФʤޤ';
+	$lang['straggrneedsbasetype']  =  'פϥǡμꤷʤФʤޤ';
+	$lang['straggrneedssfunc']  =  'פϾܴؿ̾ꤷʤФʤޤ';
+	$lang['straggrneedsstype']  =  'פξͤΥǡμꤷʤФʤޤ';
+	$lang['straggrcreated']  =  'פޤ';
+	$lang['straggrcreatedbad']  =  'פκ˼Ԥޤ';
+	$lang['straggrshowall']  =  '٤Ƥνפɽ';
 
 	// Operator Classes
 	$lang['stropclasses'] = '黻ҥ饹';
@@ -616,11 +755,11 @@
 	$lang['strrows2'] = '';
 
 	// Tablespaces
-	$lang['strtablespaces'] = 'ơ֥';
 	$lang['strtablespace'] = 'ơ֥';
+	$lang['strtablespaces']  =  'ơ֥';
 	$lang['strshowalltablespaces'] = '٤ƤΥơ֥륹ڡɽ';
 	$lang['strnotablespaces'] = 'ơ֥֤Ĥޤ';
-	$lang['strcreatetablespace'] = 'ơֺ֥';
+	$lang['strcreatetablespace'] = 'ơ֥֤';
 	$lang['strlocation'] = '';
 	$lang['strtablespaceneedsname'] = 'ơ֥̾ꤹɬפޤ';
 	$lang['strtablespaceneedsloc'] = 'ơֺ֥򤹤ǥ쥯ȥꤹɬפޤ';
@@ -632,9 +771,213 @@
 	$lang['strtablespacealtered'] = 'ơ֥֤ѹޤ';
 	$lang['strtablespacealteredbad'] = 'ơ֥֤ѹ˼Ԥޤ';
 
+	// Slony clusters
+	$lang['strcluster']  =  '饹';
+	$lang['strnoclusters']  =  '饹Ĥޤ';
+	$lang['strconfdropcluster']  =  '˥饹%sפ˴ޤ?';
+	$lang['strclusterdropped']  =  '饹˴ޤ';
+	$lang['strclusterdroppedbad']  =  '饹˴˼Ԥޤ';
+	$lang['strinitcluster']  =  '饹';
+	$lang['strclustercreated']  =  '饹ޤ';
+	$lang['strclustercreatedbad']  =  '饹ν˼Ԥޤ';
+	$lang['strclusterneedsname']  =  '饹̾Ϳɬפޤ';
+	$lang['strclusterneedsnodeid']  =  'Ρɤ ID Ϳɬפޤ';
+	
+	// Slony nodes
+	$lang['strnodes']  =  'Ρ';
+	$lang['strnonodes']  =  'ΡɤĤޤ';
+	$lang['strcreatenode']  =  'Ρɤ';
+	$lang['strid']  =  'ID';
+	$lang['stractive']  =  'ƥ';
+	$lang['strnodecreated']  =  'Ρɤޤ';
+	$lang['strnodecreatedbad']  =  'Ρɤκ˼Ԥޤ';
+	$lang['strconfdropnode']  =  '˥Ρɡ%sפ˴ޤ?';
+	$lang['strnodedropped']  =  'Ρɤ˴ޤ';
+	$lang['strnodedroppedbad']  =  'Ρɤ˴˼Ԥޤ';
+	$lang['strfailover']  =  'ե륪С';
+	$lang['strnodefailedover']  =  'Ρɤե륪Сޤ';
+	$lang['strnodefailedoverbad']  =  'ΡɤΥե륪С˼Ԥޤ';
+	$lang['strstatus']  =  '';
+$lang['strhealthy']  =  'Healthy';
+$lang['stroutofsync']  =  'Out of Sync';
+	$lang['strunknown']  =  '';	
+
+	// Slony paths	
+	$lang['strpaths']  =  'ѥ';
+	$lang['strnopaths']  =  'ѥĤޤ';
+	$lang['strcreatepath']  =  'ѥ';
+	$lang['strnodename']  =  'Ρ̾';
+	$lang['strnodeid']  =  'Ρ ID';
+	$lang['strconninfo']  =  '³ʸ';
+	$lang['strconnretry']  =  '³κƼ¹ԤޤǤÿ';
+	$lang['strpathneedsconninfo']  =  'ѥ³ʸͿɬפޤ';
+	$lang['strpathneedsconnretry']  =  '³κƼ¹ԤޤǤÿͿɬפޤ';
+	$lang['strpathcreated']  =  'ѥޤ';
+	$lang['strpathcreatedbad']  =  'ѥκ˼Ԥޤ';
+	$lang['strconfdroppath']  =  '˥ѥ%sפ˴ޤ?';
+	$lang['strpathdropped']  =  'ѥ˴ޤ';
+	$lang['strpathdroppedbad']  =  'ѥ˴˼Ԥޤ';
+
+	// Slony listens
+	$lang['strlistens']  =  'å';
+	$lang['strnolistens']  =  'å󤬸Ĥޤ';
+	$lang['strcreatelisten']  =  'å';
+	$lang['strlistencreated']  =  'åޤ';
+	$lang['strlistencreatedbad']  =  'åκ˼Ԥޤ';
+	$lang['strconfdroplisten']  =  '˥å%sפ˴ޤ?';
+	$lang['strlistendropped']  =  'å˴ޤ';
+	$lang['strlistendroppedbad']  =  'å˴˼Ԥޤ';
+
+	// Slony replication sets
+	$lang['strrepsets']  =  'ץꥱ󥻥å';
+	$lang['strnorepsets']  =  'ץꥱ󥻥åȤĤޤ';
+	$lang['strcreaterepset']  =  'ץꥱ󥻥åȤ';
+	$lang['strrepsetcreated']  =  'ץꥱ󥻥åȤޤ';
+	$lang['strrepsetcreatedbad']  =  'ץꥱ󥻥åȤκ˼Ԥޤ';
+	$lang['strconfdroprepset']  =  '˥ץꥱ󥻥åȡ%sפ˴ޤ?';
+	$lang['strrepsetdropped']  =  'ץꥱ󥻥åȤ˴ޤ';
+	$lang['strrepsetdroppedbad']  =  'ץꥱ󥻥åȤ˴˼Ԥޤ';
+	$lang['strmerge']  =  '礹';
+	$lang['strmergeinto']  =  '';
+	$lang['strrepsetmerged']  =  'ץꥱ󥻥åȤ礷ޤ';
+	$lang['strrepsetmergedbad']  =  'ץꥱ󥻥åȤ˼Ԥޤ';
+	$lang['strmove']  =  'ư';
+	$lang['strneworigin']  =  'ꥸ';
+	$lang['strrepsetmoved']  =  'ץꥱ󥻥åȤưޤ';
+	$lang['strrepsetmovedbad']  =  'ץꥱ󥻥åȤΰư˼Ԥޤ';
+	$lang['strnewrepset']  =  'ץꥱ󥻥å';
+	$lang['strlock']  =  'å';
+	$lang['strlocked']  =  'å';
+	$lang['strunlock']  =  'å';
+	$lang['strconflockrepset']  =  '˥ץꥱ󥻥åȡ%sפåޤ?';
+	$lang['strrepsetlocked']  =  'ץꥱ󥻥åȤåޤ';
+	$lang['strrepsetlockedbad']  =  'ץꥱ󥻥åȤΥå˼Ԥޤ';
+	$lang['strconfunlockrepset']  =  '˥ץꥱ󥻥åȡ%sפΥåޤ?';
+	$lang['strrepsetunlocked']  =  'ץꥱ󥻥åȤޤ';
+	$lang['strrepsetunlockedbad']  =  'ץꥱ󥻥åȤβ˼Ԥޤ';
+	$lang['stronlyonnode']  =  'ΡɤǤΤ';
+	$lang['strddlscript']  =  'DDL ץ';
+	$lang['strscriptneedsbody']  =  '٤ƤΥΡɾǼ¹Ԥ륹ץȤ󶡤ʤФʤޤ';
+	$lang['strscriptexecuted']  =  'ץꥱ󥻥åȤ DDL ץȤ¹Ԥޤ';
+	$lang['strscriptexecutedbad']  =  'ץꥱ󥻥åȤǤ DDL ץȤμ¹Ԥ˼Ԥޤ';
+	$lang['strtabletriggerstoretain']  =  'Υȥꥬ Slony ˤ̵ˤʤʤǤ礦:';
+
+	// Slony tables in replication sets
+	$lang['straddtable']  =  'ơ֥ɲä';
+	$lang['strtableneedsuniquekey']  =  'ɲäơ֥ϥץ饤ޥ꤫ˡ׵ᤷޤ';
+	$lang['strtableaddedtorepset']  =  'ץꥱ󥻥åȤ˥ơ֥ɲäޤ';
+	$lang['strtableaddedtorepsetbad']  =  'ץꥱ󥻥åȤؤΥơ֥ɲä˼Ԥޤ';
+	$lang['strconfremovetablefromrepset']  =  '˥ץꥱ󥻥åȡ%sפơ֥%sפޤ?';
+	$lang['strtableremovedfromrepset']  =  'ץꥱ󥻥åȤơ֥ޤ';
+	$lang['strtableremovedfromrepsetbad']  =  'ץꥱ󥻥åȤơ֥κ˼Ԥޤ';
+
+	// Slony sequences in replication sets
+	$lang['straddsequence']  =  '󥹤ɲä';
+	$lang['strsequenceaddedtorepset']  =  'ץꥱ󥻥åȤ˥󥹤ɲäޤ';
+	$lang['strsequenceaddedtorepsetbad']  =  'ץꥱ󥻥åȤؤΥ󥹤ɲä˼Ԥޤ';
+	$lang['strconfremovesequencefromrepset']  =  '˥ץꥱ󥻥åȡ%sפ饷󥹡%sפޤ?';
+	$lang['strsequenceremovedfromrepset']  =  'ץꥱ󥻥åȤ饷󥹤ޤ';
+	$lang['strsequenceremovedfromrepsetbad']  =  'ץꥱ󥻥åȤ饷󥹤κ˼Ԥޤ';
+
+	// Slony subscriptions
+	$lang['strsubscriptions']  =  '֥ץ';
+	$lang['strnosubscriptions']  =  '֥ץ󤬸Ĥޤ';
+
 	// Miscellaneous
-	$lang['strtopbar'] = '%s  %s ݡֹ %s ³ -- 桼%sפǥۥȡ%sפ˥';
+	$lang['strtopbar'] = 'С %2$s Υݡֹ %3$s Ǽ¹ %1$s ³ -- 桼%4$sפȤƥ(%5$s)';
 	$lang['strtimefmt'] = 'Y ǯ n  j  G:i';
 	$lang['strhelp'] = 'إ';
 	$lang['strhelpicon'] = '?';
+	$lang['strhelppagebrowser']  =  'إץڡ֥饦';
+	$lang['strselecthelppage']  =  'إץڡǤ';
+	$lang['strinvalidhelppage']  =  '̵ʥإץڡǤ';
+	$lang['strlogintitle'] = '%s ˥';
+	$lang['strlogoutmsg'] = '%s Ȥޤ';
+	$lang['strloading'] = 'ɤ߹...';
+	$lang['strerrorloading'] = 'ɤ߹Υ顼Ǥ';
+	$lang['strclicktoreload'] = 'åǺɤ߹';
+
+	// Autovacuum
+	$lang['strautovacuum']  =  'ȥХ塼'; 
+	$lang['strturnedon']  =  'ˤ'; 
+	$lang['strturnedoff']  =  'դˤ'; 
+$lang['strenabled']  =  'Enabled'; 
+	$lang['strvacuumbasethreshold']  =  'ͤ˴ŤХ塼'; 
+$lang['strvacuumscalefactor']  =  'Vacuum Scale Factor';  
+	$lang['stranalybasethreshold']  =  'ͤ˴Ť';  
+$lang['stranalyzescalefactor']  =  'Analyze Scale Factor'; 
+$lang['strvacuumcostdelay']  =  'Vacuum Cost Delay'; 
+$lang['strvacuumcostlimit']  =  'Vacuum Cost Limit';  
+
+	// Table-level Locks
+	$lang['strlocks']  =  'å';
+	$lang['strtransaction']  =  'ȥ󥶥 ID';
+	$lang['strvirtualtransaction']  =  'ۥȥ󥶥 ID';
+	$lang['strprocessid']  =  'ץ ID';
+	$lang['strmode']  =  'å⡼';
+$lang['strislockheld']  =  'Is lock held?';
+
+	// Prepared transactions
+	$lang['strpreparedxacts']  =  'ץڥѤȥ󥶥';
+	$lang['strxactid']  =  'ȥ󥶥 ID';
+	$lang['strgid']  =  ' ID';
+	
+	// Fulltext search
+	$lang['strfulltext']  =  'ʸƥȸ';
+	$lang['strftsconfig']  =  'FTS ';
+    $lang['strftsconfigs']  =  '';
+	$lang['strftscreateconfig']  =  'FTS κ';
+	$lang['strftscreatedict']  =  '';
+	$lang['strftscreatedicttemplate']  =  'Υƥץ졼Ȥ';
+	$lang['strftscreateparser']  =  'ѡ';
+	$lang['strftsnoconfigs']  =  'FTS ꤬Ĥޤ';
+	$lang['strftsconfigdropped']  =  'FTS ˴ޤ';
+	$lang['strftsconfigdroppedbad']  =  'FTS ˴˼Ԥޤ';
+	$lang['strconfdropftsconfig']  =  ' FTS %sפ˴ޤ?';
+	$lang['strconfdropftsdict']  =  ' FTS %sפ˴ޤ?';
+	$lang['strconfdropftsmapping']  =  ' FTS %sפΥޥåס%sפ˴ޤ?';
+	$lang['strftstemplate']  =  'ƥץ졼';
+	$lang['strftsparser']  =  'ѡ';
+	$lang['strftsconfigneedsname']  =  'FTS ˤ̾ꤹɬפޤ';
+	$lang['strftsconfigcreated']  =  'FTS ޤ';
+	$lang['strftsconfigcreatedbad']  =  'FTS κ˼Ԥޤ';
+$lang['strftsmapping']  =  'Mapping';
+	$lang['strftsdicts']  =  '';
+	$lang['strftsdict']  =  '';
+	$lang['strftsemptymap']  =  'FTS ޥåפǤ';
+$lang['strftswithmap']  =  'With map';
+$lang['strftsmakedefault']  =  'Make default for given locale';
+	$lang['strftsconfigaltered']  =  'FTS ѹޤ';
+	$lang['strftsconfigalteredbad']  =  'FTS ѹ˼Ԥޤ';
+	$lang['strftsconfigmap']  =  'FTS ޥå';
+	$lang['strftsparsers']  =  'FTS ѡ';
+	$lang['strftsnoparsers']  =  'ѤǤ FTS ѡޤ';
+	$lang['strftsnodicts']  =  'ѤǤ FTS 񤬤ޤ';
+	$lang['strftsdictcreated']  =  'FTS ޤ';
+	$lang['strftsdictcreatedbad']  =  'FTS κ˼Ԥޤ';
+$lang['strftslexize']  =  'Lexize';
+$lang['strftsinit']  =  'Init';
+	$lang['strftsoptionsvalues']  =  'ץ';
+	$lang['strftsdictneedsname']  =  'FTS ̾ꤷʤФʤޤ';
+	$lang['strftsdictdropped']  =  'FTS ˴ޤ';
+	$lang['strftsdictdroppedbad']  =  'FTS ˴˼Ԥޤ';
+	$lang['strftsdictaltered']  =  'FTS ѹޤ';
+	$lang['strftsdictalteredbad']  =  'FTS ѹ˼Ԥޤ';
+	$lang['strftsaddmapping']  =  'ޥåפɲä';
+	$lang['strftsspecifymappingtodrop']  =  'ޥåפ˴򤹤ˤϾʤȤ 1 ĻꤷʤФʤޤ';
+	$lang['strftsspecifyconfigtoalter']  =  'FTS ѹˤϻꤷʤФʤޤ';
+	$lang['strftsmappingdropped']  =  'FTS ޥåפ˴ޤ';
+	$lang['strftsmappingdroppedbad']  =  'FTS ޥåפ˴˼Ԥޤ';
+	$lang['strftsnodictionaries']  =  '񤬸Ĥޤ';
+	$lang['strftsmappingaltered']  =  'FTS ޥåפѹޤ';
+	$lang['strftsmappingalteredbad']  =  'FTS ޥåפѹ˼Ԥޤ';
+	$lang['strftsmappingadded']  =  'FTS ޥåפɲäޤ';
+	$lang['strftsmappingaddedbad']  =  'FTS ޥåפɲä˼Ԥޤ';
+	$lang['strftsmappingdropped']  =  'FTS ޥåפ˴ޤ';
+	$lang['strftsmappingdroppedbad']  =  'FTS ޥåפ˴˼Ԥޤ';
+	$lang['strftstabconfigs']  =  '';
+	$lang['strftstabdicts']  =  '';
+	$lang['strftstabparsers']  =  'ѡ';
+    
+    
 ?>
