@@ -4,7 +4,7 @@
 	 * Brazilian Portuguese language file for phpPgAdmin.
 	 * @maintainer ngelo Marcos Rigo (angelo_rigo@yahoo.com.br)
 	 *
-	 * $Id: portuguese-br.php,v 1.5 2004/07/12 04:18:41 chriskl Exp $
+	 * $Id: portuguese-br.php,v 1.8 2007/04/24 11:42:07 soranzo Exp $
 	 */
 
 	// Language and character set
@@ -80,7 +80,7 @@ $lang['strimport'] = 'Importar';
 	$lang['stradmin'] = 'Administrador';					
 	$lang['strvacuum'] = 'Vcuo';					
 	$lang['stranalyze'] = 'Analiza';				
-	$lang['strcluster'] = 'Cluster';				
+	$lang['strclusterindex'] = 'Cluster';				
 	$lang['strreindex'] = 'Reordenar';				
 	$lang['strrun'] = 'Rodar';						
 	$lang['stradd'] = 'Adicionar';						
@@ -97,7 +97,6 @@ $lang['strexpression'] = 'Expresso';
 $lang['strellipsis'] = '...';
 $lang['strexpand'] = 'Expandir';
 $lang['strcollapse'] = 'Diminuir';
-	$lang['strnoframes'] = 'Voc necessita um navegador com suporte a frames para utilizar esta aplicao.';
 	$lang['strbadconfig'] = 'Seu config.inc.php est desatualizado. Voc deve ger-lo novamente a partir do novo config.inc.php-dist.';
 	$lang['strnotloaded'] = 'Voc no compilou suporte  banco de dados apropriado em sua instalao do PHP.';
 	$lang['strbadschema'] = 'Esquema invlido especificado.';
@@ -261,7 +260,6 @@ $lang['stralterprivs'] = 'Alterar privilgios';
 	$lang['strcachevalue'] = 'Valor de cache';
 	$lang['strlogcount'] = 'Contador do log';
 	$lang['striscycled'] = 'Foi dado um ciclo ?';
-	$lang['striscalled'] = 'Foi chamado ?';
 	$lang['strsequenceneedsname'] = 'Voc deve dar um nome a sua sequncia.';
 	$lang['strsequencecreated'] = 'Sequncia criada.';
 	$lang['strsequencecreatedbad'] = 'Falha na criao de sequncia.'; 
