@@ -4,7 +4,7 @@
 	 * Russian KOI8 language file for phpPgAdmin. 
 	 * @maintainer Alexander Khodorivsky [askh@ukr.net]
 	 *
-	 * $Id: russian.php,v 1.9 2004/07/12 04:18:41 chriskl Exp $
+	 * $Id: russian.php,v 1.12 2007/04/24 11:42:07 soranzo Exp $
 	 */
 
 	// Language and character set
@@ -87,7 +87,7 @@
 	$lang['stradmin'] = '';
 	$lang['strvacuum'] = '';
 	$lang['stranalyze'] = '';
-	$lang['strcluster'] = '';
+	$lang['strclusterindex'] = '';
 	$lang['strclustered'] = '?';
 	$lang['strreindex'] = ' ';
 	$lang['strrun'] = '';
@@ -126,7 +126,6 @@
 	$lang['strfileimported'] = ' .';
 
 	// Error handling
-	$lang['strnoframes'] = '       ,  .';
 	$lang['strbadconfig'] = ' config.inc.php  .      config.inc.php-dist.';
 	$lang['strnotloaded'] = '  PHP   PostgreSQL.    PHP,   --with-pgsql  configure.';
 	$lang['strbadschema'] = '  .';
@@ -323,7 +322,6 @@
 	$lang['strcachevalue'] = ' ';
 	$lang['strlogcount'] = 'Log Count';
 	$lang['striscycled'] = '?';
-	$lang['striscalled'] = ' ?';
 	$lang['strsequenceneedsname'] = '    .';
 	$lang['strsequencecreated'] = ' .';
 	$lang['strsequencecreatedbad'] = '  .';
